@@ -1,4 +1,4 @@
-// $Id: createsummary.cc 1678 2013-10-23 11:29:38Z dreibh $
+// $Id: createsummary.cc 1930 2014-10-01 15:49:11Z dreibh $
 // ###########################################################################
 //             Thomas Dreibholz's R Simulation Scripts Collection
 //                  Copyright (C) 2004-2013 Thomas Dreibholz
@@ -814,16 +814,17 @@ static void usage(const char* name)
 // ###### Main program ######################################################
 int main(int argc, char** argv)
 {
-   unsigned int compressionLevel     = 9;
-   bool         interactiveMode      = true;
-   bool         splitAll             = false;
-   bool         quietMode            = false;
-   std::string  varNames             = "_NoVarNamesGiven_";
-   std::string  varValues            = "";
-   std::string  simulationsDirectory = ".";
-   std::string  resultsDirectory     = ".";
-   std::string  logFileName          = "";
-   std::string  statusFileName       = "";
+   unsigned int compressionLevel       = 9;
+   bool         interactiveMode        = true;
+   bool         splitAll               = false;
+   bool         quietMode              = false;
+   bool         ignoreScalarFileErrors = false;
+   std::string  varNames               = "_NoVarNamesGiven_";
+   std::string  varValues              = "";
+   std::string  simulationsDirectory   = ".";
+   std::string  resultsDirectory       = ".";
+   std::string  logFileName            = "";
+   std::string  statusFileName         = "";
    char         buffer[4096];
    char*        command;
 
@@ -854,6 +855,9 @@ int main(int argc, char** argv)
          else if(!(strcmp(argv[i], "-quiet"))) {
             quietMode = true;
          }
+         else if(!(strcmp(argv[i], "-ignore-scalar-file-errors"))) {
+            ignoreScalarFileErrors = true;
+         }
          else {
             usage(argv[0]);
          }
@@ -865,7 +869,7 @@ int main(int argc, char** argv)
 
 
    if(!quietMode) {
-      cout << "CreateSummary - Version 4.3.1" << endl
+      cout << "CreateSummary - Version 4.4.0" << endl
            << "=============================" << endl << endl
            << "Compression Level: " << compressionLevel << endl
            << "Interactive Mode:  " << (interactiveMode ? "on" : "off") << endl
@@ -950,6 +954,9 @@ int main(int argc, char** argv)
       else if(!(strcmp(command, "--splitall"))) {
          splitAll = true;
       }
+      else if(!(strcmp(command, "--ignore-scalar-file-errors"))) {
+         ignoreScalarFileErrors = true;
+      }
       else if(!(strncmp(command, "--level=", 8))) {
          // Deprecated, ignore ...
       }
@@ -980,15 +987,18 @@ int main(int argc, char** argv)
    if(interactiveMode) {
       cout << endl << endl;
    }
-   if(!scalarFileError) {
-      cout << "Writing scalar files..." << endl;
-      dumpScalars(simulationsDirectory, resultsDirectory, varNames,
-                  compressionLevel, interactiveMode);
-   }
-   else {
-      cerr << "Not all scalar files have been read -> aborting!" << endl;
-      exit(1);
-   }
+   if(scalarFileError) {
+      if(ignoreScalarFileErrors == false) {
+         cerr << "ERROR: Not all scalar files have been read -> aborting!" << endl;
+         exit(1);
+      }
+      else {
+         cerr << "WARNING: Not all scalar files have been read -> continuing!" << endl;
+      }
+   }      
+   cout << "Writing scalar files..." << endl;
+   dumpScalars(simulationsDirectory, resultsDirectory, varNames,
+               compressionLevel, interactiveMode);
 
 
    // ====== Clean up =======================================================
