@@ -1,7 +1,7 @@
-# $Id: plotter.R 1678 2013-10-23 11:29:38Z dreibh $
+# $Id: plotter.R 1934 2014-11-19 16:29:39Z dreibh $
 # ###########################################################################
 #             Thomas Dreibholz's R Simulation Scripts Collection
-#                  Copyright (C) 2005-2013 Thomas Dreibholz
+#                  Copyright (C) 2005-2015 Thomas Dreibholz
 #
 #               Author: Thomas Dreibholz, dreibh@iem.uni-due.de
 # ###########################################################################
@@ -91,7 +91,7 @@ rainbow2 <- function(n)
 #    else if(n == 5) {
 #       return(c("red", "#00aa00", "black", "blue", "magenta"))
 #    }
-   return(rainbow(n, gamma=2))
+   return(rainbow(n))
 }
 
 
