@@ -1,7 +1,7 @@
-/* $Id: tools.cc 1880 2014-07-10 12:35:32Z dreibh $
+/* $Id: tools.cc 1933 2014-11-17 07:41:37Z dreibh $
  *
  * Network Performance Meter
- * Copyright (C) 2009-2014 by Thomas Dreibholz
+ * Copyright (C) 2009-2015 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -579,6 +579,11 @@ int createAndBindSocket(const int             family,
    int socketFamily = family;
    if(socketFamily == AF_UNSPEC) {
       socketFamily = checkIPv6() ? AF_INET6 : AF_INET;
+      if( (localAddresses == 1) &&
+          (protocol != IPPROTO_SCTP) &&
+          (localAddressArray[0].sa.sa_family == AF_INET) ) {
+         socketFamily = AF_INET;   // Restrict to IPv4!
+      }
    }
 
    // Prepare ANY address for the corresponding family
@@ -614,9 +619,23 @@ int createAndBindSocket(const int             family,
    if(socketFamily == AF_INET6) {
       // Accept IPv4 and IPv6 connections.
       int on = 0;
-      setsockopt(sd, IPPROTO_IPV6, IPV6_BINDV6ONLY, (char *)&on, sizeof(on));
+      ext_setsockopt(sd, IPPROTO_IPV6, IPV6_BINDV6ONLY, (char *)&on, sizeof(on));
    }
 #endif
+// FIXME! Add proper, platform-independent code here!
+#ifndef __linux__
+#warning MPTCP is currently only available on Linux!
+#else
+   if((protocol == IPPROTO_MPTCP) || (protocol == IPPROTO_TCP)) {
+      const int cmtOnOff = (protocol == IPPROTO_MPTCP);
+      if(ext_setsockopt(sd, IPPROTO_TCP, TCP_MULTIPATH_ENABLE, &cmtOnOff, sizeof(cmtOnOff)) < 0) {
+         if(protocol == IPPROTO_MPTCP) {
+            return(-2);
+         }
+      }
+   }
+#endif
+
    // ====== Bind socket ====================================================
    if(localAddressCount == 0) {
       if(ext_bind(sd, &anyAddress.sa, getSocklen(&anyAddress.sa)) != 0) {
@@ -652,8 +671,20 @@ int createAndBindSocket(const int             family,
       }
       else {
          // ====== Non-SCTP bind: bind to ANY address =======================
-         if(ext_bind(sd, &localAddressArray[0].sa,
-                     getSocklen(&localAddressArray[0].sa)) != 0) {
+         sockaddr_union localAddress;
+         if(localAddressArray[0].sa.sa_family == AF_INET) {
+            memcpy(&localAddress, (void*)&localAddressArray[0].in, sizeof(sockaddr_in));
+            ((sockaddr_in*)&localAddress)->sin_port = htons(localPort);
+         }
+         else if(localAddressArray[0].sa.sa_family == AF_INET6) {
+            memcpy(&localAddress, (void*)&localAddressArray[0].in6, sizeof(sockaddr_in6));
+            ((sockaddr_in6*)&localAddress)->sin6_port = htons(localPort);
+         }
+         else {
+            assert(false);
+         }
+
+         if(ext_bind(sd, &localAddress.sa, getSocklen(&localAddress.sa)) != 0) {
             ext_close(sd);
             return(-3);
          }
@@ -971,6 +1002,9 @@ double getRandomValue(const double* valueArray, const uint8_t rng)
          value = lowest + (randomDouble() * (highest - lowest));
         }
        break;
+      case RANDOM_PARETO:
+         value = randomParetoDouble(valueArray[0], valueArray[1]);
+       break;
       default:
          value = 0.0;   // Avoids warning of uninitialized variable.
          assert(false);
@@ -993,6 +1027,9 @@ const char* getRandomGeneratorName(const uint8_t rng)
       case RANDOM_UNIFORM:
          return("uniform");
        break;
+      case RANDOM_PARETO:
+         return("pareto");
+       break;
    }
    return("(invalid!)");
 }
@@ -1087,6 +1124,21 @@ double randomExpDouble(const double p)
 }
 
 
+/* ###### Get pareto-distributed double random value ##################### */
+// m = the minimum value
+// k = the k value 
+double randomParetoDouble(const double m, const double k)
+{
+   assert(k > 0.0);
+
+   double r = randomDouble();
+   while ((r <= 0.0) || (r >= 1.0)) {
+      r = randomDouble();
+   }
+   return( m * pow(r, -1.0 / k) );
+}
+
+
 #ifdef __APPLE__
 #warning Using poll() to select() wrapper to work around broken Apple poll().
 int ext_poll_wrapper(struct pollfd* fdlist, long unsigned int count, int time)
